@@ -27,7 +27,7 @@
 #include "win32_comp.h"
 
 #ifdef USE_LTDL
-# include "../libltdl/ltdl.h"
+# include <ltdl.h>
 #else
 # ifdef HAVE_DLFCN_H
 #  ifndef WIN32
@@ -51,6 +51,7 @@
 # include <string.h>
 # include <stdlib.h>
 # include <stdio.h>
+# include <ctype.h>
 #endif
 
 #ifdef HAVE_DIRENT_H
@@ -101,5 +102,3 @@
 # endif
 #endif
 
-
-#define MAX_KEY_LEN 513 /* for gen_key */
