@@ -4,7 +4,7 @@
    (extended version)
  **********************************************************/
 
-/* $Id: xtea.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: xtea.c,v 1.7 2001/05/16 17:54:25 nmav Exp $ */
 
 /* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
  * All modifications are placed under the license of libmcrypt.
@@ -62,22 +62,20 @@ WIN32DLL_DEFINE void _mcrypt_encrypt(word32 * k, word32 * v)
 	while (sum != limit) {
 		y += (((z << 4) ^ (z >> 5)) + z) ^ (sum + k[sum & 3]);
 		sum += DELTA;
-		z +=
-		    (((y << 4) ^ (y >> 5)) + y) ^ (sum +
-						   k[(sum >> 11) & 3]);
+		z += (((y << 4) ^ (y >> 5)) + y) ^ (sum +
+						    k[(sum >> 11) & 3]);
 	}
 #else
 	while (sum != limit) {
-		y +=
-		    (((z << 4) ^ (z >> 5)) + z) ^ (sum +
-						   byteswap32(k[sum & 3]));
+		y += (((z << 4) ^ (z >> 5)) + z) ^ (sum +
+						    byteswap32(k
+							       [sum & 3]));
 		sum += DELTA;
-		z +=
-		    (((y << 4) ^ (y >> 5)) + y) ^ (sum +
-						   byteswap32(k
-							      [
-							       (sum >>
-								11) & 3]));
+		z += (((y << 4) ^ (y >> 5)) + y) ^ (sum +
+						    byteswap32(k
+							       [(sum >>
+								 11) &
+								3]));
 	}
 #endif
 
@@ -105,24 +103,22 @@ WIN32DLL_DEFINE void _mcrypt_decrypt(word32 * k, word32 * v)
 
 	sum = DELTA * (-N);
 	while (sum) {
-		z -=
-		    (((y << 4) ^ (y >> 5)) + y) ^ (sum +
-						   k[(sum >> 11) & 3]);
+		z -= (((y << 4) ^ (y >> 5)) + y) ^ (sum +
+						    k[(sum >> 11) & 3]);
 		sum -= DELTA;
 		y -= (((z << 4) ^ (z >> 5)) + z) ^ (sum + k[sum & 3]);
 #else
 	sum = DELTA * (-N);
 	while (sum) {
-		z -=
-		    (((y << 4) ^ (y >> 5)) + y) ^ (sum +
-						   byteswap32(k
-							      [
-							       (sum >>
-								11) & 3]));
+		z -= (((y << 4) ^ (y >> 5)) + y) ^ (sum +
+						    byteswap32(k
+							       [(sum >>
+								 11) &
+								3]));
 		sum -= DELTA;
-		y -=
-		    (((z << 4) ^ (z >> 5)) + z) ^ (sum +
-						   byteswap32(k[sum & 3]));
+		y -= (((z << 4) ^ (z >> 5)) + z) ^ (sum +
+						    byteswap32(k
+							       [sum & 3]));
 #endif
 	}
 #ifdef WORDS_BIGENDIAN
@@ -183,25 +179,31 @@ WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
 WIN32DLL_DEFINE int _mcrypt_self_test()
 {
 	char *keyword;
-	unsigned char *plaintext;
-	unsigned char *ciphertext;
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
 	int blocksize = _mcrypt_get_block_size(), j;
 	void *key;
 	unsigned char cipher_tmp[200];
 
 	keyword = calloc(1, _mcrypt_get_key_size());
+	if (keyword == NULL)
+		return -1;
+
 	for (j = 0; j < _mcrypt_get_key_size(); j++) {
 		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-	plaintext = malloc(blocksize);
+
 	for (j = 0; j < blocksize; j++) {
 		plaintext[j] = j % 256;
 	}
 	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
 	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 	_mcrypt_encrypt(key, (void *) ciphertext);
 
 	for (j = 0; j < blocksize; j++) {
@@ -213,14 +215,17 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 		printf("failed compatibility\n");
 		printf("Expected: %s\nGot: %s\n", CIPHER,
 		       (char *) cipher_tmp);
+		free(key);
 		return -1;
 	}
 	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
 
 	if (strcmp(ciphertext, plaintext) != 0) {
 		printf("failed internally\n");
 		return -1;
 	}
+
 	return 0;
 }
 
