@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ * Copyright (C) 1998,1999,2000,2001 Nikos Mavroyanopoulos
  * 
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
@@ -35,10 +35,10 @@
 #endif
 
 typedef struct nofb_buf {
-	word8* sd_register;
-	word8* s_register;
-	word8* enc_s_register;
-	word8* enc_sd_register;
+	byte* sd_register;
+	byte* s_register;
+	byte* enc_s_register;
+	byte* enc_sd_register;
 } nOFB_BUFFER;
 
 /* nOFB MODE */
@@ -50,8 +50,13 @@ int _init_mcrypt( nOFB_BUFFER* buf, void *key, int lenofkey, void *IV, int size)
 	buf->s_register=malloc( size);
 	buf->enc_s_register=malloc( size);
 	buf->enc_sd_register=malloc( size);
-	memmove(buf->sd_register, IV, size);
-	memmove(buf->s_register, IV, size);
+	if (IV!=NULL) {
+		memmove(buf->sd_register, IV, size);
+		memmove(buf->s_register, IV, size);
+	} else {
+		memset(buf->sd_register, 0, size);
+		memset(buf->s_register, 0, size);
+	}
 
 /* End ofb */
 
@@ -101,6 +106,7 @@ int _mcrypt( nOFB_BUFFER* buf,void *plaintext, int len, int blocksize, void* ake
 /* Put the new register */
 		memmove(buf->s_register, buf->enc_s_register, blocksize);
 	}
+	if (j==0 && len!=0) return -1;
 	return 0;
 }
 
@@ -128,7 +134,7 @@ int _mdecrypt( nOFB_BUFFER* buf, void *plaintext, int len, int blocksize, void*
 			     buf->enc_sd_register[0 +  i * sizeof(word32)])[0];
 		}
 	}
-
+	if (j==0 && len!=0) return -1;
 	return 0;
 }
 
@@ -140,5 +146,5 @@ int _mcrypt_mode_get_size () {return sizeof(nOFB_BUFFER);}
 
 
 word32 _mcrypt_mode_version() {
-	return 20000331;
+	return 20010201;
 }
